﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using AdoNetBase;
using System.Data;
using MySql.Data.MySqlClient;
using System.IO;

namespace EntityInfo
{
    /// <summary>
    /// MainWindow.xaml 的交互逻辑
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            StatusOfConnection(false);
            txtConnStr.Text = SQLHelper.GetConnectionString();
        }
        #region 非事件响应
        private void StatusOfConnection(bool isEnable)
        {
            txtTableTag.IsEnabled = isEnable;
            btnFiltrate.IsEnabled = isEnable;
            cbbTableName.IsEnabled = isEnable;
            btnCreateCode.IsEnabled = isEnable;
            txtConnStr.IsEnabled = !isEnable;
            if (isEnable)
            {
                btnConnection.Content = "断开";
            }
            else
            {
                btnConnection.Content = "连接";
                cbbTableName.ItemsSource = null;
                rtxtModel.Document.Blocks.Clear();
                rtxtDAL.Document.Blocks.Clear();
            }
        }
        private void CbbTableNameBind()
        {
            string sql = @"SELECT TABLE_NAME FROM information_schema.`TABLES` 
                        WHERE TABLE_TYPE = 'BASE TABLE' AND TABLE_NAME LIKE concat(?TableTage,'%') AND TABLE_SCHEMA = ?DataBase ;";
            DataTable dt = new DataTable();
            try
            {
                dt = SQLHelper.ExecuteDataTable(txtConnStr.Text, sql, 
                    new MySqlParameter("?TableTage", txtTableTag.Text),
                    new MySqlParameter("?DataBase", SQLHelper.GetDataBaseString(SQLHelper.GetConnectionString())));
            }
            catch (MySqlException ex)
            {
                MessageBox.Show("连接数据库失败！错误信息：" + ex.Message, "错误");
                return;
            }
            catch (Exception ex)
            {
                MessageBox.Show("不是有效的连接字符串！错误信息：" + ex.Message, "错误");
                return;
            }
            StatusOfConnection(true);
            cbbTableName.ItemsSource = dt.DefaultView;
            cbbTableName.DisplayMemberPath = "TABLE_NAME";
            cbbTableName.SelectedValuePath = "TABLE_NAME";
            cbbTableName.SelectedIndex = 0;
        }
        #endregion

        private void btnConnection_Click(object sender, RoutedEventArgs e)  //连接数据库
        {
            if ("连接" == btnConnection.Content.ToString())
            {
                if (string.IsNullOrEmpty(txtConnStr.Text))
                {
                    MessageBox.Show("请填写连接字符串!", "提示");
                    return;
                }
                SQLHelper.UpdateConnectionString(txtConnStr.Text);
                CbbTableNameBind();
            }
            else
            {
                StatusOfConnection(false); 
            }
        }

        private void btnSelectPath_Click(object sender, RoutedEventArgs e)  //选择保存文件的路径
        {
            System.Windows.Forms.FolderBrowserDialog folderBrowser = new System.Windows.Forms.FolderBrowserDialog();
            if (folderBrowser.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                txtPath.Text = folderBrowser.SelectedPath + "\\";
            }
        }

        private void btnCreateCode_Click(object sender, RoutedEventArgs e)  //生成代码
        {
            rtxtModel.Document.Blocks.Clear();
            rtxtDAL.Document.Blocks.Clear();
            DataTable dt = new DataTable();

            try
            {
                dt = SQLHelper.ExecuteDataTable(SQLHelper.GetConnectionString(), string.Format("SELECT * FROM {0} LIMIT 0,0", cbbTableName.SelectedValue.ToString()));
            }
            catch (Exception ex)
            {
                MessageBox.Show("读取数据库失败！"+ ex.Message);
                return;
            }
            EntityClassInfo entityInfo = new EntityClassInfo(dt);
            string codeEntity = CreateCode.CreateEntityClass(entityInfo);
            rtxtModel.AppendText(codeEntity);
            string codeDataAccess = CreateCode.CreateDataAccessClass(entityInfo);
            rtxtDAL.AppendText(codeDataAccess);
            if (!string.IsNullOrEmpty(txtPath.Text))
            {
                File.WriteAllText(txtPath.Text + entityInfo.ClassName + ".cs",
                    codeEntity);
                File.WriteAllText(txtPath.Text + entityInfo.ClassName + "DAL.cs",
                    codeDataAccess);
            }
        }

        private void btnFiltrate_Click(object sender, RoutedEventArgs e)    //选择
        {
            if ("连接" == btnConnection.Content.ToString())
            {
                MessageBox.Show("未连接数据库！","提示");
                return;
            }
            CbbTableNameBind();
        }



       
    }
}
